==> seedsui-react-5.6.70.tgz: package/lib/TreePicker/Menu/Tree/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["itemRender", "keyword", "value", "list", "onChange", "onExpand", "onCollapse"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
// require PrototypeArray.js
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import List from "./List";

// 树菜单选择
import { jsx as _jsx } from "react/jsx-runtime";
var Tree = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var itemRender = _ref.itemRender,
    keyword = _ref.keyword,
    _ref$value = _ref.value,
    value = _ref$value === void 0 ? [] : _ref$value,
    _ref$list = _ref.list,
    list = _ref$list === void 0 ? [] : _ref$list,
    onChange = _ref.onChange,
    onExpand = _ref.onExpand,
    onCollapse = _ref.onCollapse,
    props = _objectWithoutProperties(_ref, _excluded);
  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });
  return /*#__PURE__*/_jsx("ul", _objectSpread(_objectSpread({}, props), {}, {
    className: "treepicker-menu".concat(props.className ? ' ' + props.className : ''),
    ref: rootRef,
    children: /*#__PURE__*/_jsx(List, {
      rootRef: rootRef,
      itemRender: itemRender,
      keyword: keyword,
      value: value,
      list: list,
      onExpand: onExpand,
      onCollapse: onCollapse,
      onChange: onChange
    })
  }));
});
export default Tree;

==> seedsui-react-5.8.44.tgz: package/lib/TreePicker/Menu/Tree/index.js <==
var _excluded = ["itemRender", "keyword", "value", "list", "onChange", "onExpand", "onCollapse"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
// require PrototypeArray.js
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import List from "./List";

// 树菜单选择
var Tree = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var itemRender = _ref.itemRender,
    keyword = _ref.keyword,
    _ref$value = _ref.value,
    value = _ref$value === void 0 ? [] : _ref$value,
    _ref$list = _ref.list,
    list = _ref$list === void 0 ? [] : _ref$list,
    onChange = _ref.onChange,
    onExpand = _ref.onExpand,
    onCollapse = _ref.onCollapse,
    props = _objectWithoutProperties(_ref, _excluded);
  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });
  return /*#__PURE__*/React.createElement("ul", _extends({}, props, {
    className: "treepicker-menu".concat(props.className ? ' ' + props.className : ''),
    ref: rootRef
  }), /*#__PURE__*/React.createElement(List, {
    rootRef: rootRef,
    itemRender: itemRender,
    keyword: keyword,
    value: value,
    list: list,
    onExpand: onExpand,
    onCollapse: onCollapse,
    onChange: onChange
  }));
});
export default Tree;
